==> react-bootstrap-confirmation-1.0.2.tgz: react-bootstrap-confirmation/README.md <==
# Installation
> `npm install --save @types/react-bootstrap-confirmation`

# Summary
This package contains type definitions for react-bootstrap-confirmation (https://github.com/react-bootstrap-confirmation).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-confirmation.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-confirmation/index.d.ts)
````ts
export {};

type BootstrapStyleFlags =
    | "primary"
    | "secondary"
    | "success"
    | "danger"
    | "warning"
    | "info"
    | "light"
    | "dark"
    | "link";

interface AlertOptions {
    /**
     * A facultative title to use for the modal.
     * @default undefined
     */
    title?: string;
    /**
     * The text of the "OK" button.
     * @default "OK"
     */
    okText?: string;
    /**
     * The style of the "OK" button. Must correspond to one of the 6 button styles of Bootstrap.
     * @default "primary"
     */
    okButtonStyle?: BootstrapStyleFlags;
}

interface ConfirmOptions extends AlertOptions {
    /**
     * The text of the "Cancel" button.
     * @default "Cancel"
     */
    cancelText?: string;
    /**
     * The style of the "Cancel" button. Must correspond to one of the 6 button styles of Bootstrap.
     * @default "secondary"
     */
    cancelButtonStyle?: BootstrapStyleFlags;
}

export function alert(message: string, options?: AlertOptions): Promise<void>;
export function confirm(message: string, options?: ConfirmOptions): Promise<boolean>;

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 11:45:05 GMT
 * Dependencies: none

# Credits
These definitions were written by [Julián Bovone](https://github.com/jbovone).

==> react-bootstrap-confirmation-1.0.3.tgz: react-bootstrap-confirmation/README.md <==
# Installation
> `npm install --save @types/react-bootstrap-confirmation`

# Summary
This package contains type definitions for react-bootstrap-confirmation (https://github.com/react-bootstrap-confirmation).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-confirmation.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-confirmation/index.d.ts)
````ts
export {};

type BootstrapStyleFlags =
    | "primary"
    | "secondary"
    | "success"
    | "danger"
    | "warning"
    | "info"
    | "light"
    | "dark"
    | "link";

interface AlertOptions {
    /**
     * A facultative title to use for the modal.
     * @default undefined
     */
    title?: string;
    /**
     * The text of the "OK" button.
     * @default "OK"
     */
    okText?: string;
    /**
     * The style of the "OK" button. Must correspond to one of the 6 button styles of Bootstrap.
     * @default "primary"
     */
    okButtonStyle?: BootstrapStyleFlags;
}

interface ConfirmOptions extends AlertOptions {
    /**
     * The text of the "Cancel" button.
     * @default "Cancel"
     */
    cancelText?: string;
    /**
     * The style of the "Cancel" button. Must correspond to one of the 6 button styles of Bootstrap.
     * @default "secondary"
     */
    cancelButtonStyle?: BootstrapStyleFlags;
}

export function alert(message: string, options?: AlertOptions): Promise<void>;
export function confirm(message: string, options?: ConfirmOptions): Promise<boolean>;

````

### Additional Details
 * Last updated: Tue, 07 Nov 2023 09:09:39 GMT
 * Dependencies: none

# Credits
These definitions were written by [Julián Bovone](https://github.com/jbovone).
